package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.TypePutInStorageInfo;
import com.bonus.material.ma.service.ITypePutInStorageInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 盘点入库信息Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "盘点入库信息接口")
@RestController
@RequestMapping("/ma_type_put_in_storage_info")
public class TypePutInStorageInfoController extends BaseController
{
    @Autowired
    private ITypePutInStorageInfoService typePutInStorageInfoService;

    /**
     * 查询盘点入库信息列表
     */
    @ApiOperation(value = "查询盘点入库信息列表")
    @RequiresPermissions("ma:info:list")
    @GetMapping("/list")
    public TableDataInfo list(TypePutInStorageInfo typePutInStorageInfo)
    {
        startPage();
        List<TypePutInStorageInfo> list = typePutInStorageInfoService.selectTypePutInStorageInfoList(typePutInStorageInfo);
        return getDataTable(list);
    }

    /**
     * 导出盘点入库信息列表
     */
    @ApiOperation(value = "导出盘点入库信息列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:export")
    @SysLog(title = "盘点入库信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出盘点入库信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TypePutInStorageInfo typePutInStorageInfo)
    {
        List<TypePutInStorageInfo> list = typePutInStorageInfoService.selectTypePutInStorageInfoList(typePutInStorageInfo);
        ExcelUtil<TypePutInStorageInfo> util = new ExcelUtil<TypePutInStorageInfo>(TypePutInStorageInfo.class);
        util.exportExcel(response, list, "盘点入库信息数据");
    }

    /**
     * 获取盘点入库信息详细信息
     */
    @ApiOperation(value = "获取盘点入库信息详细信息")
    @RequiresPermissions("ma:info:query")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(typePutInStorageInfoService.selectTypePutInStorageInfoByID(ID));
    }

    /**
     * 新增盘点入库信息
     */
    @ApiOperation(value = "新增盘点入库信息")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:add")
    @SysLog(title = "盘点入库信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增盘点入库信息")
    @PostMapping
    public AjaxResult add(@RequestBody TypePutInStorageInfo typePutInStorageInfo)
    {
        return toAjax(typePutInStorageInfoService.insertTypePutInStorageInfo(typePutInStorageInfo));
    }

    /**
     * 修改盘点入库信息
     */
    @ApiOperation(value = "修改盘点入库信息")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:edit")
    @SysLog(title = "盘点入库信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改盘点入库信息")
    @PutMapping
    public AjaxResult edit(@RequestBody TypePutInStorageInfo typePutInStorageInfo)
    {
        return toAjax(typePutInStorageInfoService.updateTypePutInStorageInfo(typePutInStorageInfo));
    }

    /**
     * 删除盘点入库信息
     */
    @ApiOperation(value = "删除盘点入库信息")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:remove")
    @SysLog(title = "盘点入库信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除盘点入库信息")
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(typePutInStorageInfoService.deleteTypePutInStorageInfoByIDs(IDs));
    }
}
